@@ -6,6 +6,8 @@ import uuid
 ACT_UUID_NAMESPACE = uuid.UUID('6b159598-b585-11e7-a8e7-e83935122d71')
 FACT_IS_SOURCE = "FactIsSource"
 FACT_IS_DESTINATION = "FactIsDestination"
+ACCESS_MODES = ["Public", "RoleBased", "Explicit"]
+DEFAULT_ACCESS_MODE = "RoleBased"
 BIDIRECTIONAL_FACT = "BiDirectional"
 DEFAULT_VALIDATOR = r'(.|\n)*'
 ACT_TIME_FORMAT = "%Y-%m-%dT%H:%M:%SZ"
